basxbread package
=================

.. automodule:: basxbread
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   basxbread.contrib
   basxbread.forms
   basxbread.layout
   basxbread.settings
   basxbread.utils
   basxbread.views

Submodules
----------

basxbread.dynamic\_preferences\_registry module
-----------------------------------------------

.. automodule:: basxbread.dynamic_preferences_registry
   :members:
   :undoc-members:
   :show-inheritance:

basxbread.formatters module
---------------------------

.. automodule:: basxbread.formatters
   :members:
   :undoc-members:
   :show-inheritance:

basxbread.menu module
---------------------

.. automodule:: basxbread.menu
   :members:
   :undoc-members:
   :show-inheritance:

basxbread.middleware module
---------------------------

.. automodule:: basxbread.middleware
   :members:
   :undoc-members:
   :show-inheritance:

basxbread.querysetfield module
------------------------------

.. automodule:: basxbread.querysetfield
   :members:
   :undoc-members:
   :show-inheritance:

basxbread.urls module
---------------------

.. automodule:: basxbread.urls
   :members:
   :undoc-members:
   :show-inheritance:
